[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples

变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
  保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
  async_reduce, custom_temporary_allocation, explicit_cuda_stream,
  global_device_vector, range_view, unwrap_pointer, wrap_pointer, device

结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
  27/27 tuning headers, 78 benchmarks, 243 tests,
  60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
muh-bot
2026-08-03 12:39:26 +00:00
parent a2a5dd8f00
commit 24ef6a91b5
5439 changed files with 0 additions and 719516 deletions

View File

@@ -1,103 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#ifndef COMMON_GROUP_CUH
#define COMMON_GROUP_CUH
#include <cuda/barrier>
#include <cuda/std/cstddef>
#include <cuda/std/type_traits>
#include <cuda/warp>
#include <cuda/experimental/group.cuh>
#include "testing.cuh"
namespace
{
template <class T, cuda::std::size_t Id>
__device__ T global_barriers_storage;
//! @brief Returns reference to an array of N cuda::barrier objects with suitable thread scope for level allocated in
//! suitable address space (shared or device memory). Id parameter can be used to create unique object.
template <cuda::std::size_t N, cuda::std::size_t Id = 0, class Level>
__device__ auto& get_barriers(const Level& level) noexcept
{
constexpr auto scope = cudax::__minimum_required_scope_for<Level>();
using Barrier = cuda::barrier<scope>;
using BarriersStorage = cuda::std::aligned_storage_t<N * sizeof(Barrier), alignof(Barrier)>;
if constexpr (scope >= cuda::thread_scope_block)
{
__shared__ BarriersStorage shared_barriers_storage;
return reinterpret_cast<Barrier(&)[N]>(shared_barriers_storage);
}
else
{
return reinterpret_cast<Barrier(&)[N]>(global_barriers_storage<BarriersStorage, Id>);
}
}
struct ThreadsInWarpMappingResult
{
__device__ static constexpr ::cuda::std::size_t static_group_count()
{
return 1;
}
__device__ unsigned group_count() const
{
return 1;
}
__device__ unsigned group_rank() const
{
return 0;
}
__device__ static constexpr ::cuda::std::size_t static_unit_count()
{
return 32;
}
__device__ unsigned unit_count() const
{
return 32;
}
__device__ unsigned unit_rank() const
{
return cuda::gpu_thread.rank_as<unsigned>(cuda::warp);
}
__device__ cuda::device::lane_mask lane_mask() const noexcept
{
return cuda::device::lane_mask::all();
}
__device__ bool is_valid() const
{
return true;
}
__device__ static constexpr bool is_always_exhaustive() noexcept
{
return true;
}
__device__ static constexpr bool is_always_contiguous() noexcept
{
return true;
}
};
} // namespace
#endif // COMMON_GROUP_CUH